@@ -1,8 +1,5 @@
 #include "config.h"
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
 #include <cmocka.h>
 #include <cmocka_private.h>
 
